# Code-Based Automations
Streamline workflows for your organization by setting up code-based automations.
To eliminate manual tasks and processes, you can set up event-driven triggers that initiate automated actions. Automations ensure consistent and efficient execution of workflows, which allows you to free up your organization's resources and enable your team to focus on strategic initiatives.
Explore the tutorials in this section to learn how to set up code-based automations.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
